==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/themed/ModalParts.js <==
import * as React from 'react';
import { Text, TouchableOpacity, View } from 'react-native';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { GradientFadeOut } from '../modals/GradientFadeout';
import { useTheme } from '../services/ThemeContext';
export function ModalTitle(props) {
    const { center, children, icon = null, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(View, { style: styles.titleContainer },
        icon ? React.createElement(View, { style: styles.titleIconContainer }, icon) : null,
        React.createElement(Text, { style: [styles.titleText, center ? styles.titleCenter : null, padding] }, children)));
}
export function ModalMessage(props) {
    const { children, isWarning, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(Text, { style: [styles.messageText, padding, isWarning && styles.warningText] }, children));
}
/**
 * Renders a close button and an optional fade-out gradient.
 *
 * If you use the fade-out gradient, your scroll element's
 * `contentContainerStyle` needs `theme.rem(ModalFooter.bottomRem)`
 * worth of bottom padding, so the close button does not cover your content.
 */
export function ModalFooter(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    const { fadeOut } = props;
    const footerFadeContainer = fadeOut === true ? styles.footerFadeContainer : undefined;
    const footerFade = fadeOut === true ? styles.footerFade : undefined;
    return (React.createElement(View, { style: footerFadeContainer },
        React.createElement(View, { style: footerFade },
            React.createElement(TouchableOpacity, { onPress: props.onPress, style: styles.closeIcon, accessibilityHint: "Close Modal" },
                React.createElement(AntDesignIcon, { name: "close", size: theme.rem(1.25), color: theme.iconTappable }))),
        fadeOut !== true ? null : React.createElement(GradientFadeOut, null)));
}
ModalFooter.bottomRem = 2.5;
export function ModalScrollArea(props) {
    const { children, onCancel } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const scrollPadding = React.useMemo(() => {
        return {
            paddingBottom: theme.rem(ModalFooter.bottomRem)
        };
    }, [theme]);
    return (React.createElement(View, null,
        React.createElement(KeyboardAwareScrollView, { contentContainerStyle: scrollPadding, style: styles.scrollViewContainer, keyboardShouldPersistTaps: "handled" }, children),
        React.createElement(ModalFooter, { onPress: onCancel, fadeOut: true })));
}
const getStyles = cacheStyles((theme) => ({
    closeIcon: {
        alignItems: 'center',
        paddingBottom: theme.rem(ModalFooter.bottomRem)
    },
    scrollViewContainer: {
        margin: theme.rem(0.5),
        paddingBottom: theme.rem(2.5)
    },
    titleContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        margin: theme.rem(0.5)
    },
    titleIconContainer: {
        marginRight: theme.rem(0.5)
    },
    titleText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1.2),
        marginVertical: theme.rem(0.5)
    },
    titleCenter: {
        textAlign: 'center'
    },
    warningText: {
        color: theme.warningText
    },
    messageText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        marginVertical: theme.rem(0.5),
        textAlign: 'left'
    },
    footerFadeContainer: {
        marginBottom: theme.rem(-1)
    },
    footerFade: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 1
    }
}));

==> edge-login-ui-rn-2.20.0.tgz: package/lib/components/themed/ModalParts.js <==
/**
 * IMPORTANT: Changes in this file MUST be duplicated in edge-react-gui!
 */
import * as React from 'react';
import { ScrollView, Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { lstrings } from '../../common/locales/strings';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { GradientFadeOut } from '../modals/GradientFadeout';
import { useTheme } from '../services/ThemeContext';
export function ModalTitle(props) {
    const { center, children, icon = null, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(View, { style: styles.titleContainer },
        icon ? React.createElement(View, { style: styles.titleIconContainer }, icon) : null,
        React.createElement(Text, { style: [styles.titleText, center ? styles.titleCenter : null, padding] }, children)));
}
export function ModalMessage(props) {
    const { children, isWarning, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(Text, { style: [styles.messageText, padding, isWarning && styles.warningText] }, children));
}
/**
 * Renders a close button
 */
export function ModalFooter(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(TouchableOpacity, { onPress: props.onPress, style: styles.closeContainer },
        React.createElement(AntDesignIcon, { accessibilityHint: lstrings.modal_close_hint, color: theme.iconTappable, name: "close", size: theme.rem(1.25) })));
}
ModalFooter.bottomRem = 3;
/**
 * A consistently styled scroll area for use in modals. Should only be used
 * within ThemedModal.
 */
export function ModalScrollArea(props) {
    const { children } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(View, { style: styles.scrollContainer },
        React.createElement(ScrollView, { contentContainerStyle: styles.scrollPadding }, children),
        React.createElement(ModalFooterFade, null)));
}
/**
 * For fading the bottom of the modal if the modal caller has its own special
 * scroll implementation and does not use the ThemedModal's built-in 'scroll'
 * prop
 */
export const ModalFooterFade = () => {
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(View, { style: styles.footerFadeContainer },
        React.createElement(GradientFadeOut, null)));
};
const getStyles = cacheStyles((theme) => ({
    closeContainer: {
        alignItems: 'center',
        padding: theme.rem(1),
        marginBottom: theme.rem(-1)
    },
    scrollContainer: {
        marginBottom: theme.rem(-ModalFooter.bottomRem + 0.5)
    },
    scrollPadding: {
        paddingBottom: theme.rem(ModalFooter.bottomRem)
    },
    titleContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        margin: theme.rem(0.5)
    },
    titleIconContainer: {
        marginRight: theme.rem(0.5)
    },
    titleText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceMedium,
        fontSize: theme.rem(1.2),
        marginVertical: theme.rem(0.5)
    },
    titleCenter: {
        textAlign: 'center'
    },
    warningText: {
        color: theme.warningText
    },
    messageText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5),
        textAlign: 'left'
    },
    footerFadeContainer: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 1
    }
}));
